@@ -426,7 +426,8 @@ CREATE TABLE `system` (
   `email_forward_sms_enable` tinyint(1) NOT NULL default '0',
   `email_remain_count_enable` tinyint(1) NOT NULL default '0',
   `email_remain_count_d_enable` tinyint(1) NOT NULL default '0',
-  `session_time` int(11) NOT NULL default '24'
+  `session_time` int(11) NOT NULL default '24',
+  `disable_status` tinyint(1) NOT NULL default '0'
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
 SET character_set_client = @saved_cs_client;
 
@@ -436,7 +437,7 @@ SET character_set_client = @saved_cs_client;
 
 LOCK TABLES `system` WRITE;
 /*!40000 ALTER TABLE `system` DISABLE KEYS */;
-INSERT INTO `system` VALUES (70,'goipsms',3,118,'','','','',25,0,5,0,5,'',0,1,0,3,0,0,0,0,0,24);
+INSERT INTO `system` VALUES (70,'goipsms',3,118,'','','','',25,0,5,0,5,'',0,1,0,3,0,0,0,0,0,24,0);
 
 /*!40000 ALTER TABLE `system` ENABLE KEYS */;
 UNLOCK TABLES;
