@@ -4,8 +4,6 @@ $dbuser='goip';		//database username
 $dbpw='goip';		//database password 
 $dbname='goip';		//database name
 $goipcronport='44444';  //goipcron port
-$version="V1.21.1";
-$bdate="Build 201503";
 $charset='utf8';
 $endless_send=0;
 $re_ask_timer=3;
